@@ -14,6 +14,7 @@ def join(endpoint):
 
     # Run install-master script from internet
     install(join_info)
+    setup_system_service()
 
 
 def install(join_info):
@@ -32,3 +33,12 @@ def install(join_info):
 
     print(process.stderr.readline().decode())
 
+
+def setup_system_service():
+    response = requests.get(url='https://raw.githubusercontent.com/AI-Ocean/kubernetes-install-scripts/main/ocean-agent-worker.service')
+    with open("/lib/systemd/system/ocean-agent-worker.service", "w") as f:
+        f.write(response.text)
+
+    subprocess.check_output(['systemctl', 'daemon-reload'])
+    subprocess.check_output(['systemctl', 'enable', 'ocean-agent-worker'])
+    subprocess.check_output(['systemctl', 'restart', 'ocean-agent-worker'])
