@@ -4,6 +4,7 @@ import click
 
 from worker.cmd.hello import hello as worker_hello
 from worker.cmd.join import join as worker_join
+from worker.cmd.serve import serve as worker_serve
 
 logging.basicConfig(
     format='%(asctime)s %(levelname)-8s %(message)s',
@@ -28,5 +29,10 @@ def join(master_endpoint):
     worker_join(master_endpoint)
 
 
+@cli.command()
+def serve():
+    worker_serve()
+
+
 if __name__ == "__main__":
     cli()
